@@ -1,9 +1,9 @@
 from figcli.commands.config_context import ConfigContext
 from figcli.commands.types.config import ConfigCommand
 from figcli.config import *
-from figcli.data.dao.config import ConfigDao
-from figcli.data.dao.ssm import SsmDao
+from figgy.data.dao.ssm import SsmDao
 from figcli.extras.key_utils import KeyUtils
+from figcli.io.output import Output
 from figcli.svcs.observability.anonymous_usage_tracker import AnonymousUsageTracker
 from figcli.svcs.observability.version_tracker import VersionTracker
 from figcli.utils.utils import Utils
@@ -21,6 +21,7 @@ class Validate(ConfigCommand):
         self.example = f"{self.c.fg_bl}{CLI_NAME} config {self.command_printable} " \
                        f"--env dev --config /path/to/config{self.c.rs}"
         self._FILE_PREFIX = "file://"
+        self._out = Output(colors_enabled)
 
     def _validate(self):
         missing_key = False
@@ -43,18 +44,16 @@ class Validate(ConfigCommand):
         print()
         for name in all_names:
             if name not in all_param_names:
-                print(f"Fig missing from {self.c.fg_yl}{self.run_env}{self.c.rs} environment"
-                      f" Parameter Store: {self.c.fg_yl}{name}{self.c.rs}")
+                self._out.warn(f"Fig missing from [[{self.run_env}]] environment Parameter Store: [[{name}]]")
                 missing_key = True
             else:
-                print(f"Fig found in ParameterStore: {self.c.fg_bl}{name}{self.c.rs}.")
+                self._out.print(f"Fig found in ParameterStore: [[{name}]].")
 
         if missing_key:
             print("\n\n")
             self._utils.error_exit(f"{MISSING_PS_NAME_MESSAGE}")
         else:
-            print(f"{self.c.fg_gr}Success! All figs have been located in the {self.c.rs}{self.c.fg_bl}{self.run_env}"
-                  f"{self.c.rs} ParameterStore!")
+            self._out.success(f"\nSuccess! All figs have been located in the [[{self.run_env}]] ParameterStore!")
 
     @VersionTracker.notify_user
     @AnonymousUsageTracker.track_command_usage
