@@ -15,9 +15,13 @@ class Provider(Enum):
     def sso_providers() -> List["Provider"]:
         return [Provider.OKTA, Provider.GOOGLE]
 
+    @staticmethod
+    def cloud_providers() -> List["Provider"]:
+        return [Provider.AWS_BASTION, Provider.OKTA, Provider.GOOGLE]
+
     @staticmethod
     def names():
-        return [provider.name for provider in Provider]
+        return [provider.name for provider in Provider.cloud_providers()]
 
     @staticmethod
     def values():
